==> ministra-5.6.8.zip: stalker_portal/server/Lib/AdminPanelEvents.php <==
<?php

namespace Ministra\Lib;

use Ministra\Lib\e7ad172977eb8d4fc1927f1037c2a8f5\f1861167937df2425a26a0c9763b3b8f;
use Ministra\Lib\e7ad172977eb8d4fc1927f1037c2a8f5\b009b335728cd8e4f099e9618546ca1d9\fa1bbe77f401c6a3f5707becb14513ad;
use Ministra\Lib\e7ad172977eb8d4fc1927f1037c2a8f5\O7d24a478f79395d954dd4b4b90a76a13;
class AdminPanelEvents extends \Ministra\Lib\SysEvent
{
    private $postData = [];
    private $user_list = [];
    public function __construct($postData = [])
    {
        parent::__construct();
        $this->postData = $postData;
    }
    public function setPostData($postData)
    {
        $this->postData = $postData;
        return $this;
    }
    public function get_userlist_all()
    {
        if (\array_key_exists('event', $this->postData) && $this->postData['event'] == 'send_msg' || $this->postData['event'] == 'send_msg_with_video') {
            $this->user_list = \Ministra\Lib\e7ad172977eb8d4fc1927f1037c2a8f5\f1861167937df2425a26a0c9763b3b8f::E88055c79bf5f460df07f8db9eead321a();
        } else {
            $this->user_list = \Ministra\Lib\e7ad172977eb8d4fc1927f1037c2a8f5\f1861167937df2425a26a0c9763b3b8f::L91ae16e873340eb8e9b1b9de0c988ab8();
        }
        return $this;
    }
    public function get_userlist_by_user_list()
    {
        if (\array_key_exists('user_list_type', $this->postData) && $this->postData['user_list_type'] == 'by_user_list' && !empty($this->postData['file_name'])) {
            $file_name = \sys_get_temp_dir() . '/' . $this->postData['file_name'];
            if (\is_writable($file_name)) {
                $file_data = \explode(';', \file_get_contents($file_name));
                foreach ($file_data as $mac) {
                    $uid = \Ministra\Lib\e7ad172977eb8d4fc1927f1037c2a8f5\f1861167937df2425a26a0c9763b3b8f::r7cfb20b3f88061656522d16fe7ef70a6($mac);
                    if ($uid) {
                        $this->user_list[] = $uid;
                    }
                }
            }
            @\unlink($file_name);
        }
        return $this;
    }
    public function get_userlist_by_group()
    {
        if (\array_key_exists('group_id', $this->postData) && (int) $this->postData['group_id'] > 0) {
            $this->user_list = \Ministra\Lib\e7ad172977eb8d4fc1927f1037c2a8f5\O7d24a478f79395d954dd4b4b90a76a13::getInstance()->from('stb_in_group')->where(['stb_group_id' => $this->postData['group_id']])->get()->all('uid');
        }
        return $this;
    }
    public function get_userlist_by_pattern()
    {
        if (!empty($this->postData['pattern'])) {
            $param = [];
            if ($this->postData['pattern'] == 'MAG100') {
                $param['hd'] = 0;
            } else {
                $param['stb_type'] = $this->postData['pattern'];
            }
            $this->user_list = \Ministra\Lib\e7ad172977eb8d4fc1927f1037c2a8f5\f1861167937df2425a26a0c9763b3b8f::c2935a88132bd2b1a6042edb02e903f4e($param);
        }
        return $this;
    }
    public function get_userlist_by_filter()
    {
        if (!empty($this->postData['filter_set'])) {
            $filter_set = \Ministra\Lib\Filters::getInstance();
            $filter_set->setResellerID(\array_key_exists('reseller', $this->postData) ? $this->postData['reseller'] : 0);
            $filter_set->initData('users', 'id');
            $curr_filter_set = \Ministra\Lib\e7ad172977eb8d4fc1927f1037c2a8f5\O7d24a478f79395d954dd4b4b90a76a13::getInstance()->from('filter_set')->where(['id' => $this->postData['filter_set']])->get()->first();
            if (!empty($curr_filter_set) && ($unserialize_data = @\Ministra\Lib\e7ad172977eb8d4fc1927f1037c2a8f5\b009b335728cd8e4f099e9618546ca1d9\fa1bbe77f401c6a3f5707becb14513ad::U14f6e17e22660d6a254d5165f6a0c21d($curr_filter_set['filter_set']))) {
                $filter_data = [];
                foreach ($unserialize_data as $row) {
                    $filter_data[$row[0]] = $row;
                }
                $filters_with_cond = \array_values(\array_filter(\array_map(function ($row) use($filter_data) {
                    if (\array_key_exists($row['text_id'], $filter_data)) {
                        $filters_with_cond = [];
                        $parsed_values = [];
                        switch ($row['type']) {
                            case 'DATETIME':
                                $parsed_values = \explode('|', (string) $filter_data[$row['text_id']][2]);
                                $filters_with_cond[] = [$row['method'], '>=', !empty($parsed_values[0]) ? $parsed_values[0] : 0];
                                $filters_with_cond[] = [$row['method'], '<=', !empty($parsed_values[1]) ? $parsed_values[1] : (empty($parsed_values[0]) ? \time() : 0)];
                                break;
                            case 'NUMBER' && \strpos($filter_data[$row['text_id']][2], '|') !== false:
                            case 'VALUES_SET' && \strpos($filter_data[$row['text_id']][2], '|') !== false:
                                $parsed_values = \explode('|', (string) $filter_data[$row['text_id']][2]);
                                if ($row['text_id'] == 'status' || $row['text_id'] == 'state') {
                                    $parsed_values = \array_map(function ($filter_val) {
                                        return (int) ($filter_val - 1 > 0);
                                    }, $parsed_values);
                                }
                                $filters_with_cond[] = [$row['method'], 'in', $parsed_values];
                                break;
                            default:
                                $filters_with_cond[] = [$row['method'], $filter_data[$row['text_id']][1], $filter_data[$row['text_id']][2]];
                                break;
                        }
                        return $filters_with_cond;
                    }
                }, $filter_set->getFilters())));
                if (\is_array($filters_with_cond) && !empty($filters_with_cond)) {
                    $filters_with_cond = \count($filters_with_cond) > 1 ? \call_user_func_array('array_merge', \array_values($filters_with_cond)) : \current($filters_with_cond);
                }
                $filtered_arr = \array_map(function ($filter) use($filter_set) {
                    $filter_set->initData('users', 'id');
                    \call_user_func_array([$filter_set, 'setFilters'], $filter);
                    return $filter_set->getData();
                }, $filters_with_cond);
                $filtered_merge = \array_unique(\call_user_func_array('array_merge', \array_values($filtered_arr)));
                \array_unshift($filtered_arr, $filtered_merge);
                $this->user_list = \array_unique(\array_values(\call_user_func_array('array_intersect', \array_values($filtered_arr))));
            }
        }
        return $this;
    }
    public function get_userlist_single()
    {
        $ids = [];
        if (\array_key_exists('mac', $this->postData) && \Ministra\Lib\e7ad172977eb8d4fc1927f1037c2a8f5\f1861167937df2425a26a0c9763b3b8f::c6a35228d46e59418dd6e54198374817($this->postData['mac'])) {
            $ids[] = \Ministra\Lib\e7ad172977eb8d4fc1927f1037c2a8f5\f1861167937df2425a26a0c9763b3b8f::r7cfb20b3f88061656522d16fe7ef70a6($this->postData['mac']);
        } elseif (\array_key_exists('id', $this->postData) && \is_numeric($this->postData['id'])) {
            $ids[] = $this->postData['id'];
        }
        $this->user_list = $ids;
        return $this;
    }
    public function get_userlist_selected()
    {
        $ids = \array_key_exists('selected_ids', $this->postData) ? \explode(',', $this->postData['selected_ids']) : [];
        $this->user_list = $ids;
        return $this;
    }
    public function cleanAndSetUsers()
    {
        $all_users = \Ministra\Lib\e7ad172977eb8d4fc1927f1037c2a8f5\O7d24a478f79395d954dd4b4b90a76a13::getInstance()->from('users')->get()->all('id');
        if (!empty($all_users)) {
            $this->user_list = \array_intersect($this->user_list, $all_users);
        }
        $this->setUserListById($this->user_list);
        return $this;
    }
    public function set_event_send_msg()
    {
        if (\array_key_exists('msg', $this->postData) && \array_key_exists('header', $this->postData)) {
            if (!empty($this->postData['reboot_after_ok'])) {
                $this->sendMsgAndReboot($this->postData['msg'], $this->postData['header']);
            } else {
                $this->sendMsg($this->postData['msg'], $this->postData['header']);
            }
            return true;
        }
        return false;
    }
    public function set_event_reboot()
    {
        $this->sendReboot();
        return true;
    }
    public function set_event_reload_portal()
    {
        $this->sendReloadPortal();
        return true;
    }
    public function set_event_update_channels()
    {
        $this->sendUpdateChannels();
        return true;
    }
    public function set_event_play_channel()
    {
        if (\array_key_exists('channel', $this->postData)) {
            $this->sendPlayChannel($this->postData['channel']);
            return true;
        }
        return false;
    }
    public function set_event_play_radio_channel()
    {
        if (\array_key_exists('channel', $this->postData)) {
            $this->sendPlayRadioChannel($this->postData['channel']);
            return true;
        }
        return false;
    }
    public function set_event_mount_all_storages()
    {
        $this->sendMountAllStorages();
        return true;
    }
    public function set_event_cut_off()
    {
        if (!\is_array($this->user_list)) {
            $this->user_list = [$this->user_list];
        }
        \Ministra\Lib\e7ad172977eb8d4fc1927f1037c2a8f5\O7d24a478f79395d954dd4b4b90a76a13::getInstance()->where(['id in (' . \implode(',', $this->user_list) . ') and 1' => 1])->update('users', ['status' => 1, 'last_change_status' => 'NOW()']);
        $this->sendCutOff();
        return true;
    }
    public function set_event_update_image()
    {
        $this->sendUpdateImage();
        return true;
    }
    public function set_event_send_msg_with_video()
    {
        if (\array_key_exists('msg', $this->postData) && \array_key_exists('header', $this->postData) && !empty($this->postData['video_url'])) {
            $this->sendMsgWithVideo($this->postData['msg'], $this->postData['video_url'], $this->postData['header']);
            return true;
        }
        return false;
    }
    public function getUserList()
    {
        return $this->user_list;
    }
}

==> ministra-5.6.10.zip: stalker_portal/server/Lib/AdminPanelEvents.php <==
<?php

namespace Ministra\Lib;

use Ministra\Lib\k43ef11a9578c2293bdfdd714ecc1b172\B91ebc4a2170a66056f8eac1009f6bb85;
use Ministra\Lib\k43ef11a9578c2293bdfdd714ecc1b172\e19b518dccc8206e14e113c869a7ec85\e87b1fd04909f2937a56ec5b5d50aac0;
use Ministra\Lib\k43ef11a9578c2293bdfdd714ecc1b172\x6c4456d08c1312d52a4f35d8b06875b7;
use Ministra\Lib\k43ef11a9578c2293bdfdd714ecc1b172\g974965637b063c004a1dfc7c145520ca;
class AdminPanelEvents extends \Ministra\Lib\SysEvent
{
    private $postData = [];
    private $user_list = [];
    public function __construct($postData = [])
    {
        parent::__construct();
        $this->postData = $postData;
    }
    public function setPostData($postData)
    {
        $this->postData = $postData;
        return $this;
    }
    public function get_userlist_all()
    {
        if (\array_key_exists('event', $this->postData) && $this->postData['event'] == 'send_msg' || $this->postData['event'] == 'update_image' || $this->postData['event'] == 'send_msg_with_video') {
            $this->user_list = \Ministra\Lib\k43ef11a9578c2293bdfdd714ecc1b172\B91ebc4a2170a66056f8eac1009f6bb85::i567947f8b6eac795bf700e0fac905d37();
        } else {
            $this->user_list = \Ministra\Lib\k43ef11a9578c2293bdfdd714ecc1b172\B91ebc4a2170a66056f8eac1009f6bb85::o9cd6e61088e2d5d25d34881eb93ebb42();
        }
        return $this;
    }
    public function get_userlist_by_user_list()
    {
        if (\array_key_exists('user_list_type', $this->postData) && $this->postData['user_list_type'] == 'by_user_list' && !empty($this->postData['file_name'])) {
            $file_name = \sys_get_temp_dir() . '/' . $this->postData['file_name'];
            if (\is_writable($file_name)) {
                $file_data = \explode(';', \file_get_contents($file_name));
                foreach ($file_data as $mac) {
                    $uid = \Ministra\Lib\k43ef11a9578c2293bdfdd714ecc1b172\B91ebc4a2170a66056f8eac1009f6bb85::W278f7696f0090f223114de31e39db2f7($mac);
                    if ($uid) {
                        $this->user_list[] = $uid;
                    }
                }
            }
            @\unlink($file_name);
        }
        return $this;
    }
    public function get_userlist_by_group()
    {
        if (\array_key_exists('group_id', $this->postData) && (int) $this->postData['group_id'] > 0) {
            $this->user_list = \Ministra\Lib\k43ef11a9578c2293bdfdd714ecc1b172\x6c4456d08c1312d52a4f35d8b06875b7::getInstance()->from('stb_in_group')->where(['stb_group_id' => $this->postData['group_id']])->get()->all('uid');
        }
        return $this;
    }
    public function get_userlist_by_pattern()
    {
        if (!empty($this->postData['pattern'])) {
            $param = [];
            if ($this->postData['pattern'] == 'MAG100') {
                $param['hd'] = 0;
            } else {
                $param['stb_type'] = $this->postData['pattern'];
            }
            $this->user_list = \Ministra\Lib\k43ef11a9578c2293bdfdd714ecc1b172\B91ebc4a2170a66056f8eac1009f6bb85::l60848cb7073905c227e47b48de4bf884($param);
        }
        return $this;
    }
    public function get_userlist_by_filter()
    {
        if (!empty($this->postData['filter_set'])) {
            $filter_set = \Ministra\Lib\Filters::getInstance();
            $filter_set->setResellerID(\array_key_exists('reseller', $this->postData) ? $this->postData['reseller'] : 0);
            $filter_set->initData('users', 'id');
            $curr_filter_set = \Ministra\Lib\k43ef11a9578c2293bdfdd714ecc1b172\x6c4456d08c1312d52a4f35d8b06875b7::getInstance()->from('filter_set')->where(['id' => $this->postData['filter_set']])->get()->first();
            if (!empty($curr_filter_set) && ($unserialize_data = @\Ministra\Lib\k43ef11a9578c2293bdfdd714ecc1b172\e19b518dccc8206e14e113c869a7ec85\e87b1fd04909f2937a56ec5b5d50aac0::g42f505f47727c35750dfd0f6823c28f6($curr_filter_set['filter_set']))) {
                $filter_data = [];
                foreach ($unserialize_data as $row) {
                    $filter_data[$row[0]] = $row;
                }
                $filters_with_cond = \array_values(\array_filter(\array_map(function ($row) use($filter_data) {
                    if (\array_key_exists($row['text_id'], $filter_data)) {
                        $filters_with_cond = [];
                        $parsed_values = [];
                        switch ($row['type']) {
                            case 'DATETIME':
                                $parsed_values = \explode('|', (string) $filter_data[$row['text_id']][2]);
                                $filters_with_cond[] = [$row['method'], '>=', !empty($parsed_values[0]) ? $parsed_values[0] : 0];
                                $filters_with_cond[] = [$row['method'], '<=', !empty($parsed_values[1]) ? $parsed_values[1] : (empty($parsed_values[0]) ? \time() : 0)];
                                break;
                            case 'NUMBER' && \strpos($filter_data[$row['text_id']][2], '|') !== false:
                            case 'VALUES_SET' && \strpos($filter_data[$row['text_id']][2], '|') !== false:
                                $parsed_values = \explode('|', (string) $filter_data[$row['text_id']][2]);
                                if ($row['text_id'] == 'status' || $row['text_id'] == 'state') {
                                    $parsed_values = \array_map(function ($filter_val) {
                                        return (int) ($filter_val - 1 > 0);
                                    }, $parsed_values);
                                }
                                $filters_with_cond[] = [$row['method'], 'in', $parsed_values];
                                break;
                            default:
                                $filters_with_cond[] = [$row['method'], $filter_data[$row['text_id']][1], $filter_data[$row['text_id']][2]];
                                break;
                        }
                        return $filters_with_cond;
                    }
                }, $filter_set->getFilters())));
                if (\is_array($filters_with_cond) && !empty($filters_with_cond)) {
                    $filters_with_cond = \count($filters_with_cond) > 1 ? \call_user_func_array('array_merge', \array_values($filters_with_cond)) : \current($filters_with_cond);
                }
                $filtered_arr = \array_map(function ($filter) use($filter_set) {
                    $filter_set->initData('users', 'id');
                    \call_user_func_array([$filter_set, 'setFilters'], $filter);
                    return $filter_set->getData();
                }, $filters_with_cond);
                $filtered_merge = \array_unique(\call_user_func_array('array_merge', \array_values($filtered_arr)));
                \array_unshift($filtered_arr, $filtered_merge);
                $this->user_list = \array_unique(\array_values(\call_user_func_array('array_intersect', \array_values($filtered_arr))));
            }
        }
        return $this;
    }
    public function get_userlist_single()
    {
        $ids = [];
        if (\array_key_exists('mac', $this->postData) && \Ministra\Lib\k43ef11a9578c2293bdfdd714ecc1b172\B91ebc4a2170a66056f8eac1009f6bb85::v01bca43c6f80eb0c1fc32ba911ad467c($this->postData['mac'])) {
            $ids[] = \Ministra\Lib\k43ef11a9578c2293bdfdd714ecc1b172\B91ebc4a2170a66056f8eac1009f6bb85::W278f7696f0090f223114de31e39db2f7($this->postData['mac']);
        } elseif (\array_key_exists('id', $this->postData) && \is_numeric($this->postData['id'])) {
            $ids[] = $this->postData['id'];
        }
        $this->user_list = $ids;
        return $this;
    }
    public function get_userlist_selected()
    {
        $ids = \array_key_exists('selected_ids', $this->postData) ? \explode(',', $this->postData['selected_ids']) : [];
        $this->user_list = $ids;
        return $this;
    }
    public function cleanAndSetUsers()
    {
        $all_users = \Ministra\Lib\k43ef11a9578c2293bdfdd714ecc1b172\x6c4456d08c1312d52a4f35d8b06875b7::getInstance()->from('users')->get()->all('id');
        if (!empty($all_users)) {
            $this->user_list = \array_intersect($this->user_list, $all_users);
        }
        $this->setUserListById($this->user_list);
        return $this;
    }
    public function set_event_send_msg()
    {
        if (\array_key_exists('msg', $this->postData) && \array_key_exists('header', $this->postData)) {
            if (!empty($this->postData['reboot_after_ok'])) {
                $this->sendMsgAndReboot($this->postData['msg'], $this->postData['header']);
            } else {
                $this->sendMsg($this->postData['msg'], $this->postData['header']);
            }
            return true;
        }
        return false;
    }
    public function set_event_reboot()
    {
        $this->sendReboot();
        return true;
    }
    public function set_event_reload_portal()
    {
        $this->sendReloadPortal();
        return true;
    }
    public function set_event_update_channels()
    {
        $this->sendUpdateChannels();
        return true;
    }
    public function set_event_play_channel()
    {
        if (\array_key_exists('channel', $this->postData)) {
            $this->sendPlayChannel($this->postData['channel']);
            return true;
        }
        return false;
    }
    public function set_event_play_radio_channel()
    {
        if (\array_key_exists('channel', $this->postData)) {
            $this->sendPlayRadioChannel($this->postData['channel']);
            return true;
        }
        return false;
    }
    public function set_event_mount_all_storages()
    {
        $this->sendMountAllStorages();
        return true;
    }
    public function set_event_cut_off()
    {
        if (!\is_array($this->user_list)) {
            $this->user_list = [$this->user_list];
        }
        \Ministra\Lib\k43ef11a9578c2293bdfdd714ecc1b172\x6c4456d08c1312d52a4f35d8b06875b7::getInstance()->where(['id in (' . \implode(',', $this->user_list) . ') and 1' => 1])->update('users', ['status' => 1, 'last_change_status' => 'NOW()']);
        $this->sendCutOff();
        return true;
    }
    public function set_event_update_image()
    {
        $usersData = \Ministra\Lib\k43ef11a9578c2293bdfdd714ecc1b172\x6c4456d08c1312d52a4f35d8b06875b7::getInstance()->select(['id', 'stb_type'])->from('users')->in('id', $this->getUserList())->get()->all();
        $stbTypesList = [];
        foreach ($usersData as $row) {
            if (!\array_key_exists($row['stb_type'], $stbTypesList)) {
                $stbTypesList[$row['stb_type']] = [];
            }
            $stbTypesList[$row['stb_type']][] = $row['id'];
        }
        foreach ($stbTypesList as $stbType => $usersList) {
            $updateUrl = \Ministra\Lib\k43ef11a9578c2293bdfdd714ecc1b172\g974965637b063c004a1dfc7c145520ca::U4eda3b0aa1f36fe3fa0e3b4072f075ab($stbType);
            if (empty($updateUrl)) {
                continue;
            }
            $eventClone = clone $this;
            $eventClone->setUserListById($usersList);
            $eventClone->setPostFunctionParam('update_image', $updateUrl);
            $eventClone->sendUpdateImage();
        }
        return true;
    }
    public function set_event_send_msg_with_video()
    {
        if (\array_key_exists('msg', $this->postData) && \array_key_exists('header', $this->postData) && !empty($this->postData['video_url'])) {
            $this->sendMsgWithVideo($this->postData['msg'], $this->postData['video_url'], $this->postData['header']);
            return true;
        }
        return false;
    }
    public function getUserList()
    {
        return $this->user_list;
    }
}
